==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/DataConsentTrans.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * DataConsentTrans
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class DataConsentTrans extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<DataConsentTrans> {

    /** DataConsentTrans attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** languageId column */
        public static final String LANGUAGEID ="languageId";
        /** title column */
        public static final String TITLE ="title";
        /** description column */
        public static final String DESCRIPTION ="description";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("languageId");
            list.add("title");
            list.add("description");

            return list;
        }
    }

    /** Field attributes */
    public static DataConsentTransFieldAttributes FieldAttributes=new DataConsentTransFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public DataConsentTransFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * dataConsent relation.
         *
         * @return the dataConsent bean relations attributes.
         */
        public DataConsent.Relations dataConsent()
        {
            DataConsent c = new DataConsent();
            return c.new Relations(this.buildPath("dataConsent"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the LANGUAGEID path.
         *
         * @return the path
         */
        public String LANGUAGEID()
        {
            return buildPath(Fields.LANGUAGEID);
        }
        /**
         * the TITLE path.
         *
         * @return the path
         */
        public String TITLE()
        {
            return buildPath(Fields.TITLE);
        }
        /**
         * the DESCRIPTION path.
         *
         * @return the path
         */
        public String DESCRIPTION()
        {
            return buildPath(Fields.DESCRIPTION);
        }
    }

    /** The dummy obj. */
    private static DataConsentTrans dummyObj=new DataConsentTrans();

    /**
     * Get DataConsentTrans Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<DataConsentTrans> getDataSet()
    {
        return new HibernateDataSet<DataConsentTrans>(DataConsentTrans.class, HibernateUtil.getSessionFactory("DIFRepository"),
            DataConsentTrans.getPKFieldListAsString(), DataConsentTrans.FieldAttributes);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<DataConsentTrans> getDataSetInstance()
    {
        return new DataConsentTrans().getDataSet();
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("dataConsent".equalsIgnoreCase(attributeName))
            return dataConsent;
        if("languageId".equalsIgnoreCase(attributeName))
            return languageId;
        if("title".equalsIgnoreCase(attributeName))
            return title;
        if("description".equalsIgnoreCase(attributeName))
            return description;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("dataConsent".equalsIgnoreCase(attributeName))
            dataConsent =(DataConsent)attributeValue;
        if("languageId".equalsIgnoreCase(attributeName))
            languageId =(String)attributeValue;
        if("title".equalsIgnoreCase(attributeName))
            title =(String)attributeValue;
        if("description".equalsIgnoreCase(attributeName))
            description =(String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** dataConsent private attribute */
    private DataConsent dataConsent;

    /** languageId private attribute */
    private String languageId;

    /** title private attribute */
    private String title;

    /** description private attribute */
    private String description;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public DataConsentTrans() {
    }

	/** 
	 * minimal constructor
	 *
     * @param dataConsent the dataConsent
     * @param languageId the languageId
     * @param title the title
    }
	 */
    public DataConsentTrans(DataConsent dataConsent, String languageId, String title) {
        this.dataConsent = dataConsent;
        this.languageId = languageId;
        this.title = title;
    }

    /**
     * full constructor
	 *
     * @param dataConsent the dataConsent
     * @param languageId the languageId
     * @param title the title
     * @param description the description
     */
    public DataConsentTrans(DataConsent dataConsent, String languageId, String title, String description) {
        this.dataConsent = dataConsent;
        this.languageId = languageId;
        this.title = title;
        this.description = description;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return DataConsentTrans modified instance
     */
    public DataConsentTrans setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * dataConsent getter method
     *
     * @return dataConsent method
     */
    public DataConsent getDataConsent() {
        return this.dataConsent;
    }
    
    /**       
     * dataConsent setter method
     *
     * @param dataConsent the dataConsent
     *
     * @return DataConsentTrans modified instance
     */
    public DataConsentTrans setDataConsent(DataConsent dataConsent) {
        this.dataConsent = dataConsent;
        
        return this;
    }
    /**       
     * languageId getter method
     *
     * @return languageId method
     */
    public String getLanguageId() {
        return this.languageId;
    }
    
    /**       
     * languageId setter method
     *
     * @param languageId the languageId
     *
     * @return DataConsentTrans modified instance
     */
    public DataConsentTrans setLanguageId(String languageId) {
        this.languageId = languageId;
        
        return this;
    }
    /**       
     * title getter method
     *
     * @return title method
     */
    public String getTitle() {
        return this.title;
    }
    
    /**       
     * title setter method
     *
     * @param title the title
     *
     * @return DataConsentTrans modified instance
     */
    public DataConsentTrans setTitle(String title) {
        this.title = title;
        
        return this;
    }
    /**       
     * description getter method
     *
     * @return description method
     */
    public String getDescription() {
        return this.description;
    }
    
    /**       
     * description setter method
     *
     * @param description the description
     *
     * @return DataConsentTrans modified instance
     */
    public DataConsentTrans setDescription(String description) {
        this.description = description;
        
        return this;
    }

    /**
     * Creates a String representation of the DataConsentTrans object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("languageId").append("='").append(getLanguageId()).append("' ");			
        buffer.append("title").append("='").append(getTitle()).append("' ");			
        buffer.append("description").append("='").append(getDescription()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the DataConsentTrans object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(DataConsentTrans other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("languageId".equalsIgnoreCase(attributeName))
        	this.languageId = attributeValue;

        if ("title".equalsIgnoreCase(attributeName))
        	this.title = attributeValue;

        if ("description".equalsIgnoreCase(attributeName))
        	this.description = attributeValue;

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static DataConsentTrans getProxy(Session session, Long id)
    {
        return(DataConsentTrans)session.load(DataConsentTrans.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static DataConsentTrans getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        DataConsentTrans result = (DataConsentTrans)session.load(DataConsentTrans.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static DataConsentTrans getInstance(Session session, Long id)
    {
        return(DataConsentTrans)session.get(DataConsentTrans.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static DataConsentTrans getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        DataConsentTrans result = (DataConsentTrans)session.get(DataConsentTrans.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/DataConsentTrans.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * DataConsentTrans
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class DataConsentTrans extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<DataConsentTrans> {

    /**
    * Constant with the session factory ID
    */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /** DataConsentTrans attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** languageId column */
        public static final String LANGUAGEID ="languageId";
        /** title column */
        public static final String TITLE ="title";
        /** description column */
        public static final String DESCRIPTION ="description";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("languageId");
            list.add("title");
            list.add("description");

            return list;
        }
    }

    /** Field attributes */
    public static DataConsentTransFieldAttributes FieldAttributes=new DataConsentTransFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public DataConsentTransFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * dataConsent relation.
         *
         * @return the dataConsent bean relations attributes.
         */
        public DataConsent.Relations dataConsent()
        {
            DataConsent c = new DataConsent();
            return c.new Relations(this.buildPath("dataConsent"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the LANGUAGEID path.
         *
         * @return the path
         */
        public String LANGUAGEID()
        {
            return buildPath(Fields.LANGUAGEID);
        }
        /**
         * the TITLE path.
         *
         * @return the path
         */
        public String TITLE()
        {
            return buildPath(Fields.TITLE);
        }
        /**
         * the DESCRIPTION path.
         *
         * @return the path
         */
        public String DESCRIPTION()
        {
            return buildPath(Fields.DESCRIPTION);
        }
    }

    /** The dummy obj. */
    private static DataConsentTrans dummyObj=new DataConsentTrans();

    /**
     * Get DataConsentTrans Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<DataConsentTrans> getDataSet()
    {
        return getDataSetInstance();
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<DataConsentTrans> getDataSetInstance()
    {
        return new HibernateDataSet<DataConsentTrans>(DataConsentTrans.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
            DataConsentTrans.getPKFieldListAsString(), DataConsentTrans.FieldAttributes);
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("dataConsent".equalsIgnoreCase(attributeName))
            return dataConsent;
        if("languageId".equalsIgnoreCase(attributeName))
            return languageId;
        if("title".equalsIgnoreCase(attributeName))
            return title;
        if("description".equalsIgnoreCase(attributeName))
            return description;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("dataConsent".equalsIgnoreCase(attributeName))
            dataConsent =(DataConsent)attributeValue;
        if("languageId".equalsIgnoreCase(attributeName))
            languageId =(String)attributeValue;
        if("title".equalsIgnoreCase(attributeName))
            title =(String)attributeValue;
        if("description".equalsIgnoreCase(attributeName))
            description =(String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** dataConsent private attribute */
    private DataConsent dataConsent;

    /** languageId private attribute */
    private String languageId;

    /** title private attribute */
    private String title;

    /** description private attribute */
    private String description;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * Gets description field.
     *
     * @return the description field
     */
    @Override
    public String getDescriptionField()
    {
        return FieldAttributes.getDescriptionField();
    }

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    @Override
    public List<String> getPKFields()
    {
        return getPKFieldList();
    }

    /**
     * Is composite PK.
     *
     * @return the boolean
     */
    @Override
    public boolean isCompositePK()
    {
        return this.getPKFieldList().size() > 1;
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {
        if (attributeName.contains("."))
        {
            return this.getAttributeAsStringParseBeanPath(attributeName);
        }
        else
        {
            Object value = getAttribute(attributeName);

            if (value == null)
                return "";
            else {
                return value.toString().trim();
            }
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public DataConsentTrans() {
    }

	/** 
	 * minimal constructor
	 *
     * @param dataConsent the dataConsent
     * @param languageId the languageId
     * @param title the title
    }
	 */
    public DataConsentTrans(DataConsent dataConsent, String languageId, String title) {
        this.dataConsent = dataConsent;
        this.languageId = languageId;
        this.title = title;
    }

    /**
     * full constructor
	 *
     * @param dataConsent the dataConsent
     * @param languageId the languageId
     * @param title the title
     * @param description the description
     */
    public DataConsentTrans(DataConsent dataConsent, String languageId, String title, String description) {
        this.dataConsent = dataConsent;
        this.languageId = languageId;
        this.title = title;
        this.description = description;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return DataConsentTrans modified instance
     */
    public DataConsentTrans setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * dataConsent getter method
     *
     * @return dataConsent method
     */
    public DataConsent getDataConsent() {
        return this.dataConsent;
    }
    
    /**       
     * dataConsent setter method
     *
     * @param dataConsent the dataConsent
     *
     * @return DataConsentTrans modified instance
     */
    public DataConsentTrans setDataConsent(DataConsent dataConsent) {
        this.dataConsent = dataConsent;
        
        return this;
    }
    /**       
     * languageId getter method
     *
     * @return languageId method
     */
    public String getLanguageId() {
        return this.languageId;
    }
    
    /**       
     * languageId setter method
     *
     * @param languageId the languageId
     *
     * @return DataConsentTrans modified instance
     */
    public DataConsentTrans setLanguageId(String languageId) {
        this.languageId = languageId;
        
        return this;
    }
    /**       
     * title getter method
     *
     * @return title method
     */
    public String getTitle() {
        return this.title;
    }
    
    /**       
     * title setter method
     *
     * @param title the title
     *
     * @return DataConsentTrans modified instance
     */
    public DataConsentTrans setTitle(String title) {
        this.title = title;
        
        return this;
    }
    /**       
     * description getter method
     *
     * @return description method
     */
    public String getDescription() {
        return this.description;
    }
    
    /**       
     * description setter method
     *
     * @param description the description
     *
     * @return DataConsentTrans modified instance
     */
    public DataConsentTrans setDescription(String description) {
        this.description = description;
        
        return this;
    }

    /**
     * dataConsent id getter method
     *
     * @return dataConsent id method
     */
    public Long getDataConsentId() {
        if (this.dataConsent == null)
            return null;
        else
            return this.dataConsent.getId();
    }

    /**
     * DataConsent proxy setter method from id.
     *
     * @return DataConsentTrans modified instance
     */
    public DataConsentTrans setDataConsentProxyFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.dataConsent = null;
        else
            this.dataConsent = DataConsent.getProxy(id);

        return this;
    }

    /**
     * DataConsent instance setter method from id.
     *
     * @return DataConsentTrans modified instance
     */
    public DataConsentTrans setDataConsentInstanceFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.dataConsent = null;
        else
            this.dataConsent = DataConsent.getInstance(id);

        return this;
    }

    /**
     * Creates a String representation of the DataConsentTrans object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("languageId").append("='").append(getLanguageId()).append("' ");			
        buffer.append("title").append("='").append(getTitle()).append("' ");			
        buffer.append("description").append("='").append(getDescription()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the DataConsentTrans object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(DataConsentTrans other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("languageId".equalsIgnoreCase(attributeName))
        	this.languageId = attributeValue;

        if ("title".equalsIgnoreCase(attributeName))
        	this.title = attributeValue;

        if ("description".equalsIgnoreCase(attributeName))
        	this.description = attributeValue;

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static DataConsentTrans getProxy(Session session, Long id)
    {
        return(DataConsentTrans)session.load(DataConsentTrans.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static DataConsentTrans getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        DataConsentTrans result = (DataConsentTrans)session.load(DataConsentTrans.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static DataConsentTrans getInstanceForSession(Session session, Long id)
    {
        return(DataConsentTrans)session.get(DataConsentTrans.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static DataConsentTrans getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        DataConsentTrans result = (DataConsentTrans)session.get(DataConsentTrans.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}
